@@ -1,2 +1,2 @@
-coef.glmnet=function(object,s=NULL,exact=FALSE,...)
+coef.glmnet=function(object,s=NULL,exact=TRUE,...)
   predict(object,s=s,type="coefficients",exact=exact)
