@@ -1,4 +1,4 @@
-predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=FALSE,offset,...){
+predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=TRUE,offset,...){
   type=match.arg(type)
     ### remember that although the fortran lognet makes predictions
   ### for the first class, we make predictions for the second class
@@ -10,7 +10,12 @@ nfit=NextMethod("predict")
            pp=exp(-nfit)
            1/(1+pp)
          },
-         class=ifelse(nfit>0,2,1),
+         class={
+           cnum=ifelse(nfit>0,2,1)
+           clet=object$classnames[cnum]
+           if(is.matrix(cnum))clet=array(clet,dim(cnum),dimnames(cnum))
+           clet
+         },
          nfit
          )
 }  
